#
# spec file for package iniparser
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# if bumping this, also update baselibs.conf
%define sonum 1
Name:           iniparser
Version:        4.1
Release:        3.3
Summary:        Library to parse ini files
License:        MIT
Group:          System/Libraries
URL:            http://ndevilla.free.fr/iniparser/
Source:         https://github.com/ndevilla/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch00:        iniparser_remove_rpath.patch
Patch01:        Fail-testrun-on-test-failure.patch
Patch02:        Fix-buffer-overflow-from-sprintf.patch
Patch03:        Fix-tests-on-32bit.patch
# PATCH-FIX-SUSE handle-null-return-getstring.patch bsc#1211889 -- CVE-2023-33461: NULL pointer dereference in iniparser_getboolean()
# https://github.com/ndevilla/iniparser/pull/146
Patch04:        handle-null-return-getstring.patch

%description
Libiniparser offers parsing of ini files from the C level.

%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1100
%define libiniparser_name libiniparser%{sonum}
%else
%define libiniparser_name libiniparser
%endif

%package -n %{libiniparser_name}
Summary:        Library to parse ini files
Group:          System/Libraries

%description -n %{libiniparser_name}
Libiniparser offers parsing of ini files from the C level.

This package includes the libiniparser%{sonum} library.

%package -n libiniparser-devel
Summary:        Libraries and Header Files to Develop Programs with libiniparser Support
Group:          Development/Libraries/C and C++
%if 0%{?suse_version} == 0 || 0%{?suse_version} > 1100
Requires:       %{libiniparser_name} = %{version}
%else
Requires:       libiniparser = %{version}
%endif

%description -n libiniparser-devel
This package contains the static libraries and header files needed to
develop programs which make use of the libiniparser programming
interface.

The libiniparser offers parsing of ini files from the C level.	See a
complete documentation in HTML format, from the
%{_docdir}/libiniparser-devel directory open the file
html/index.html with any HTML-capable browser.

Libraries and Header Files to Develop Programs with iniparser Support.

%prep
%setup -q
%autopatch -p1

%build
make %{?_smp_mflags} CFLAGS="%{optflags} -fPIC"

%install
install -d -m 0755 %{buildroot}%{_includedir}
install -d -m 0755 %{buildroot}%{_libdir}
install -m 0755 libiniparser.so.%{sonum} %{buildroot}%{_libdir}
install -m 0644 src/{dictionary,iniparser}.h %{buildroot}%{_includedir}
ln -s -f libiniparser.so.%{sonum} %{buildroot}%{_libdir}/libiniparser.so

%check
ln -s libiniparser.so.%{sonum} libiniparser.so
make %{?_smp_mflags} check

%post -n %{libiniparser_name} -p /sbin/ldconfig
%postun -n %{libiniparser_name} -p /sbin/ldconfig

%files -n %{libiniparser_name}
%{_libdir}/libiniparser.so.*
%doc LICENSE

%files -n libiniparser-devel
%{_includedir}/*.h
%{_libdir}/libiniparser.so
%doc html

%changelog
* Fri Jun  2 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Add handle-null-return-getstring.patch (bsc#1211889)
  CVE-2023-33461: NULL pointer dereference in iniparser_getboolean()
* Wed Aug 24 2022 Michal Suchanek <msuchanek@suse.com>
- Add fixes since 4.1
  + Fail-testrun-on-test-failure.patch
  + Fix-buffer-overflow-from-sprintf.patch
- Fix tests failing on 32bit architectures
  + Fix-tests-on-32bit.patch
* Sat Nov 11 2017 aavindraa@gmail.com
- Update to 4.1 (stable release)
  + For full change set, see:
    https://github.com/ndevilla/iniparser/compare/b1c4ac6f...v4.1
- Cleanup with spec-cleaner
- Rebase iniparser_remove_rpath.patch
- so number bumped from 0 to 1 per upstream policy
* Sat Jun 27 2015 lmuelle@suse.com
- Update to git snapshot 20150605 b1c4ac6f
  + Use the same xstrdup implementation for both source file
  + allocate memory for string termination
  + Add travis.yml
  + iniparser_getseckeys doesn't return a malloc ptr anymore
  + One more static + whitespace cleanup
  + Prevent negative array index access when a line solely consists of
    newlines and spaces
  + Made strstrip() static
- Remove libiniparser from baselibs.conf
* Thu Jun 19 2014 lmuelle@suse.com
- Update to git snapshot 20140619 c5beb80a
  + Fix coverity issues
  + Fix resource leaks
  + Modify to build unbounded keys & values from multi-line input
  + Fix crash with crafted ini files
  + Makefile fixes: Library build, targets
  + Prevent compiler warning when compiling for 64 bit
  + Build system improvements
- Update iniparser_remove_rpath.patch
* Mon Mar 17 2014 lmuelle@suse.com
- Remove superfluous obsoletes *-64bit in the ifarch ppc64 case; (bnc#437293).
* Fri Jun  7 2013 lmuelle@suse.com
- Include LICENSE file from the source tar ball.
* Tue Jun  5 2012 lmuelle@suse.com
- Define library name and use it instead of libiniparser0.
* Sun Jun  3 2012 lmuelle@suse.com
- Use the unversioned libiniparser name on pre-11.2 systems only.
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libiniparser0.
- Remove unused debug_package_requires define.
* Sat Apr 21 2012 lars@samba.org
- Update to version 3.1.
  + Const'ified input string arguments
- Update to version 3.0.
  + Single function to set values in a dict: iniparser_set()
  + Bug corrected for lines containing only \n
  + Enhanced documentation
  + C++ nonsense removed
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Thu Aug 28 2008 anschneider@suse.de
- create packages following the shlib policy
- build only the shared library
* Wed Aug 20 2008 meissner@suse.de
- use RPM_OPT_FLAGS, libiniparser.a can be 644
* Mon May  5 2008 anschneider@suse.de
- build without rpath
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig* errors
* Sun May 27 2007 lmuelle@suse.de
- Update to version 2.17.
  + Apply some const and fix c++ warnings.
  + Merge revision 19928 from samba.org subversion.
  + Applied patches to the Makefile to build a shared library.
* Sun May 20 2007 lmuelle@suse.de
- Remove requires on release from devel packages.
* Tue Sep 26 2006 gd@suse.de
- Update to version 2.15
  - documentation fixes
* Tue Apr 11 2006 lmuelle@suse.de
- Inital SuSE RPM.
